============
Installation
============


You can install the library with `pip` using the following command:

.. code-block::

  # Basic installation of the library 
  pip install holisticai
  
  # bias mitigation support
  pip install holisticai[bias] 

  # additional packages for explainability metrics and plots
  pip install holisticai[explainability]

  # install all packages for security strategies
  pip install holisticai[security]
